==> pandoc-crossref-0.3.4.0-65-x86_64.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.3.4.0
id: pandoc-crossref-0.3.4.0-DYNqGeSiQZYKNNuvZN5YOY
key: pandoc-crossref-0.3.4.0-DYNqGeSiQZYKNNuvZN5YOY
license: GPL-2.0-only
maintainer: root@livid.pp.ru
author: Nikolay Yakimov
homepage: https://github.com/lierdakil/pandoc-crossref#readme
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
abi: b9e980e37db316bd451487266d5246be
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Settings
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Paths_pandoc_crossref
import-dirs: /usr/lib/ghc-8.6.4/site-local/pandoc-crossref-0.3.4.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/pandoc-crossref-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.3.4.0-DYNqGeSiQZYKNNuvZN5YOY
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-accessor-0.2.2.8-AYq93Bw1A2YHILUYropyUn
    data-accessor-template-0.2.1.16-Iitk7dZ2vVF1n1UiWEY5LJ
    data-accessor-transformers-0.2.1.7-5wbZaRH8II89QeXVhYgfQ4
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4 directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pandoc-2.7.1-EUc67Fb4eKpJIEsucaNzy4
    pandoc-types-1.17.5.4-2QdQziDCe9mGjiKCzVIzNQ
    roman-numerals-0.5.1.5-3za2AazuRwa402pxXteKHr
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    text-1.2.3.1 utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.3.4.0-67-x86_64.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.3.4.0
id: pandoc-crossref-0.3.4.0-KE3LtW5e7liBw4u5srfJtn
key: pandoc-crossref-0.3.4.0-KE3LtW5e7liBw4u5srfJtn
license: GPL-2.0-only
maintainer: root@livid.pp.ru
author: Nikolay Yakimov
homepage: https://github.com/lierdakil/pandoc-crossref#readme
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
abi: a7a209cbd2ef51f1c9735513057253a8
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Settings
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Paths_pandoc_crossref
import-dirs: /usr/lib/ghc-8.6.4/site-local/pandoc-crossref-0.3.4.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/pandoc-crossref-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.3.4.0-KE3LtW5e7liBw4u5srfJtn
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-accessor-0.2.2.8-AYq93Bw1A2YHILUYropyUn
    data-accessor-template-0.2.1.16-Iitk7dZ2vVF1n1UiWEY5LJ
    data-accessor-transformers-0.2.1.7-5wbZaRH8II89QeXVhYgfQ4
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4 directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pandoc-2.7.1-88GnEkm5FcAFw5Tlo76Tnj
    pandoc-types-1.17.5.4-Dv3jPr775yC6XC1hEZTVYr
    roman-numerals-0.5.1.5-3za2AazuRwa402pxXteKHr
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    text-1.2.3.1 utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
